<?php

namespace Drupal\content_export_yaml\Form;

use Drupal\content_export_yaml\ContentExport;
use Drupal\content_export_yaml\DBManager;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ContentExportSettingForm.
 */
class ContentExportSettingForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'content_export_yaml.contentexportsetting',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_export_setting_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('content_export_yaml.contentexportsetting');
    $export = new ContentExport() ;
    $bd = new DBManager();
    $param = \Drupal::request()->query->all();
    $export->load_exported_all();
    $status = 0;
    if(isset($param['file'])){
        $status = $export->importByFilePath($param['file']);
    }


    $form['path_export_content_folder'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Path export content folder'),
      '#description' => $this->t('This folder path where your content will store , Example : /sites/default/files'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('path_export_content_folder'),
    ];
//    if($content_path){
//      $form['upload_yml'] = [
//        '#type' => 'managed_file',
//        '#title' => t('Upload Content YML'),
//        '#upload_validators' => array(
//          'file_validate_extensions' => array('yml'),
//          'file_validate_size' => array(25600000),
//        ),
//        '#upload_location' => 'public://',
//        '#required' => FALSE,
//      ];
//    }

//    if(isset($param['download'])){
//      $link = $export->download_yml($param['download']);
//      $theme_download = '<a style="padding: 5px 15px" href="'.$link.'"> CLICK HERE TO DOWNLOAD YOUR FILE </a>' ;
//      $form['theme_download'] = [
//        '#markup' => $theme_download
//      ];
//    }

    $header = array(
      array('data' => t('ID'), 'field' => 'number'),
      array('data' => t('Entity ID'), 'field' => 'entity_id'),
      array('data' => t('Label'), 'field' => 'label'),
      array('data' => t('Entity Type'), 'field' => 'entity_type'),
      array('data' => t('Bundle'), 'field' => 'bundle', 'sort' => 'desc'),
      array('data' => t('Action'), 'field' => 'is_exported')
    );
    $table_exit = \Drupal::database()->schema()->tableExists('content_export_yaml');
    if($table_exit){
    $query = \Drupal::database()->select('content_export_yaml','exp');
    $query->fields('exp', array('number', 'entity_id', 'label','entity_type','bundle','file'));
    $query->addField('exp','file','operation');
    $table_sort = $query->extend('Drupal\Core\Database\Query\TableSortExtender')->orderByHeader($header);
    $pager = $table_sort->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(10);
    $result = $pager->execute();
    $rows =[];
    if(!empty($result)){
      foreach($result as $row) {
        $action = "";
        if (file_exists(DRUPAL_ROOT.$row->file) === FALSE) {
          $bd->delete_by_id($row->entity_id);
        }else{
          $check_node = $export->is_exist_node($row->entity_id,$row->bundle,$row->entity_type);
          if (empty($check_node)) {
            $action ="<a href='/admin/config/content_export_yaml/setting?file=".$row->file."'>Click to import</a>";
          }
          if($action==""){
            $action="<b>Imported</b>";
          }
          $action.=" | <a href='/admin/config/content_export_yaml/setting?rm=".$row->file."'>remove</a>";
          $row->operation = t($action);
          unset($row->file);
          $rows[] = array('data' => (array) $row);
        }

      }
    }
    $form['theme_element_header'] = array(
      '#markup' => t('List of All Exported Entity')
    );

    $form['content_export_yaml'] = array(
      '#theme' => 'table', '#header' => $header,
      '#rows' => $rows
    );
    $form['pager'] = array(
      '#type' => 'pager'
    );
    }
    if($status!=0 && $status!=-1){
      $status = -1 ;
      $export->redirectTo("/admin/config/content_export_yaml/setting");
    }
    if(isset($param['rm'])){
      $export->delete($param['rm']);
      $status = -3 ;
    }
    if($status ==-1){
      drupal_set_message('Content Imported Suscessfully', 'status');
    }
    if($status ==-3){
      drupal_set_message('Content Exported Deleted Suscessfully', 'status');
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('content_export_yaml.contentexportsetting')
      ->set('path_export_content_folder', $form_state->getValue('path_export_content_folder'))
      ->save();
  }

}
